# Venture

A Dmenu / Rofi / Wofi menu to open projects and files in your favorite editor!



### Dependancies
Venture supports three UI providers: dmenu, rofi, and wofi. It is expected that you have the one you intend to use installed.

## Installation

```
$ pip install venture
```